@@ -10,15 +10,12 @@
 #'
 #' @return A ggplot2-object.
 #'
-#' @examples
-#' \donttest{
-#' if (require("randomForest") && require("performance")) {
-#'   m <- lm(mpg ~ wt + cyl + gear + disp, data = mtcars)
-#'   result <- check_distribution(m)
-#'   result
-#'   plot(result)
-#' }
-#' }
+#' @examplesIf identical(Sys.getenv("NOT_CRAN"), "true") && require("randomForest")
+#' library(performance)
+#' m <<- lm(mpg ~ wt + cyl + gear + disp, data = mtcars)
+#' result <- check_distribution(m)
+#' result
+#' plot(result)
 #' @export
 plot.see_check_distribution <- function(x, size_point = 2, panel = TRUE, ...) {
   model <- .retrieve_data(x)
@@ -27,9 +24,11 @@ plot.see_check_distribution <- function(x, size_point = 2, panel = TRUE, ...) {
   dat <- data.frame(
     x = factor(c(x$Distribution, x$Distribution), levels = rev(sort(unique(x$Distribution)))),
     y = c(x$p_Response, x$p_Residuals),
-    group = factor(c(rep("Response", length(x$p_Response)), rep("Residuals", length(x$p_Residuals))),
+    group = factor(
+      c(rep("Response", length(x$p_Response)), rep("Residuals", length(x$p_Residuals))),
       levels = c("Response", "Residuals")
-    )
+    ),
+    stringsAsFactors = FALSE
   )
 
   # remove all zero-probabilities
@@ -41,16 +40,25 @@ plot.see_check_distribution <- function(x, size_point = 2, panel = TRUE, ...) {
   # default legend-position
   lp <- ifelse(isTRUE(panel), "right", "bottom")
 
-  p1 <- ggplot(dat, aes(
-    y = .data$x,
-    x = .data$y,
-    colour = .data$group
-  )) +
-    geom_linerange(aes(xmin = 0, xmax = .data$y),
-      position = position_dodge(.4),
-      size = .8
+  p1 <- ggplot(
+    dat,
+    aes(
+      y = .data$x,
+      x = .data$y,
+      colour = .data$group
+    )
+  ) +
+    geom_linerange(
+      aes(xmin = 0, xmax = .data$y),
+      position = position_dodge(0.4),
+      linewidth = 0.8,
+      na.rm = TRUE
+    ) +
+    geom_point(
+      size = size_point,
+      position = position_dodge(0.4),
+      na.rm = TRUE
     ) +
-    geom_point(size = size_point, position = position_dodge(.4)) +
     labs(
       y = NULL,
       x = NULL,
@@ -93,7 +101,8 @@ plot.see_check_distribution <- function(x, size_point = 2, panel = TRUE, ...) {
   p3 <- ggplot(dat2, aes(x = .data$x)) +
     geom_histogram(
       fill = "#f44336", colour = bar_color,
-      binwidth = sqrt(length(vars(.data$x)))
+      binwidth = sqrt(length(vars(.data$x))),
+      na.rm = TRUE
     ) +
     labs(x = NULL, y = NULL, title = "Distribution of Response") +
     theme_lucid()
@@ -118,7 +127,8 @@ plot.see_check_distribution_numeric <- function(x,
 
   dat <- data.frame(
     x = factor(x$Distribution, levels = rev(sort(unique(x$Distribution)))),
-    y = x$p_Vector
+    y = x$p_Vector,
+    stringsAsFactors = FALSE
   )
 
   # remove all zero-probabilities
@@ -131,14 +141,33 @@ plot.see_check_distribution_numeric <- function(x,
   lp <- ifelse(isTRUE(panel), "right", "bottom")
 
   p1 <- ggplot(dat, aes(y = .data$x, x = .data$y)) +
-    geom_linerange(aes(xmin = 0, xmax = .data$y), position = position_dodge(.4), size = .8) +
-    geom_point(size = size_point, position = position_dodge(.4)) +
-    labs(y = NULL, x = NULL, fill = NULL, colour = NULL, title = "Predicted Distribution of Vector") +
-    scale_x_continuous(labels = .percents, expand = c(0, 0), limits = c(0, max_y)) +
+    geom_linerange(
+      aes(xmin = 0, xmax = .data$y),
+      position = position_dodge(0.4),
+      linewidth = 0.8,
+      na.rm = TRUE
+    ) +
+    geom_point(
+      size = size_point,
+      position = position_dodge(0.4),
+      na.rm = TRUE
+    ) +
+    labs(
+      y = NULL,
+      x = NULL,
+      fill = NULL,
+      colour = NULL,
+      title = "Predicted Distribution of Vector"
+    ) +
+    scale_x_continuous(
+      labels = .percents,
+      expand = c(0, 0),
+      limits = c(0, max_y)
+    ) +
     theme_lucid(legend.position = lp)
 
   dat1 <- as.data.frame(stats::density(vec))
-  dat2 <- data.frame(x = vec)
+  dat2 <- data.frame(x = vec, stringsAsFactors = FALSE)
 
   p2 <- ggplot(dat1, aes(x = .data$x, y = .data$y)) +
     geom_line() +
@@ -148,14 +177,15 @@ plot.see_check_distribution_numeric <- function(x,
   p3 <- ggplot(dat2, aes(x = .data$x)) +
     geom_histogram(
       colour = theme_lucid()$panel.background$fill,
-      binwidth = sqrt(length(vars(.data$x)))
+      binwidth = sqrt(length(vars(.data$x))),
+      na.rm = TRUE
     ) +
     labs(x = NULL, y = NULL, title = "Distribution of Vector") +
     theme_lucid()
 
   if (panel) {
     insight::check_if_installed("patchwork")
-    return(p1 / (p2 | p3) + patchwork::plot_layout(nrow = 2))
+    return(p1 / (p2 | p3) + patchwork::plot_layout(nrow = 2L))
   } else {
     return(list(p1, p2, p3))
   }
