@@ -9,7 +9,7 @@
 #' scales for 'ggplot2'. Color scales are based on
 #' <https://materialui.co/colors>.
 #'
-#' References: Lüdecke et al. (2021) \doi{10.21105/joss.03393}.
+#' References: Luedecke et al. (2021) \doi{10.21105/joss.03393}.
 #'
 #' @docType package
 #' @aliases see see-package
@@ -17,6 +17,13 @@
 #' @keywords internal
 "_PACKAGE"
 
+## see namespace: start
+##
+#' @import ggplot2
+#'
+## see namespace: end
+NULL
+
 # Suppress R CMD check note
 # Namespace in Imports field not imported from: PKG
 #   All declared Imports should be used.
