@@ -1,6 +1,6 @@
-skip_if_not_or_load_if_installed("patchwork")
-
 test_that("`plots()` works", {
+  skip_if_not_installed("patchwork")
+
   p1 <- ggplot(iris, aes(x = Petal.Length, y = Sepal.Width)) +
     geom_point()
   p2 <- ggplot(iris, aes(x = Petal.Length)) +
